# SpikeExtractors (LEGACY)
The `spikeextractors` package has now been integrated into [spikeinterface](https://github.com/SpikeInterface/spikeinterface).

This package will be maintained for a while for bug fixes only, then it will be deprecated.

New features and improvements will only be implemented for the `spikeinterface` package.
